Databases
=========

Sage includes mathematical databases as standard or optional packages,
and provides convenient interfaces for easy access to the databases.

Standard databases
------------------

These databases are available in the standard install of Sage or if Sage can access
Internet.

.. toctree::
   :maxdepth: 1

   sage/databases/conway
   sage/databases/oeis
   sage/databases/sloane
   sage/databases/findstat

Optional databases
------------------

The following databases require you to install optional packages before full access.

.. toctree::
   :maxdepth: 1

   sage/databases/cunningham_tables
   sage/databases/knotinfo_db
   sage/databases/cubic_hecke_db
   sage/databases/symbolic_data
   sage/databases/cremona
   sage/databases/stein_watkins
   sage/databases/jones
   sage/databases/db_class_polynomials
   sage/databases/db_modular_polynomials
   sage/databases/odlyzko

.. include:: ../footer.txt
